#
# spec file for package photoqt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           photoqt
Version:        3.4
Release:        2.4
Summary:        A Qt-based image viewer
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://photoqt.org/
Source0:        https://gitlab.com/lspies/photoqt/-/archive/v%{version}/%{name}-v%{version}.tar.bz2
Patch0:         photoqt-exiv2.patch
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  freeimage-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5PlatformHeaders-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(IL)
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Multimedia) >= 5.4.0
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(poppler-qt5)
BuildRequires:  pkgconfig(pugixml)

%description
PhotoQt is a configurable image viewer.

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
%cmake -DCRYPTKEY:STRING=4242 \
       -DCHROMECAST=OFF \
       -DVIDEO_MPV=OFF

make %{?_smp_mflags}

%install
%cmake_install

%files
%license COPYING
%doc CHANGELOG
%{_bindir}/%{name}
%{_datadir}/metainfo/org.photoqt.PhotoQt.metainfo.xml
%{_datadir}/applications/org.photoqt.PhotoQt*.desktop
%{_datadir}/icons/hicolor/*/apps/org.photoqt.PhotoQt.png

%changelog
* Thu Nov  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add photoqt-exiv2.patch: Fix linking exiv2.
* Mon Oct  9 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.4:
  * add: resvg support for rendering SVG files
  * add: thumbnails/filedialog: show thumbnails of very small
    images at the original size
  * add: notification when deleting image without confirmation
  * add: cmake flag to disable webp support (webp suport
    is enabled by default)
  * add: missing settings elements to connect PhotoQt with
    imgur.com account
  * improve: shortcuts: duplicate shortcuts automatically
    reasigned with undo button
  * improve: remove all modal popups
  * improve: update imgur element with updated element from
    qt6 port
  * improve: relace unavailable element with notification element
    from qt6 port
  * improve: port qt6 element to export images to different format
    to qt5 version
  * fix: map explorer: clicking on images to focus on
    their location
  * fix: setting internal commands as part of custom shortcut
    commands
  * fix: fileview: delete image through rightclick without
    selecting first
  * fix: thumbnail provider caches thumbnail images properly
* Tue Jun 27 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.3:
  * add: all new shortcuts engine
  * add: floating element to show location of current image on map
  * add: map explorer to show all images in current folder with
    location data on interactive map
  * add: reset button to restore initial stage of main image
  * add: setting to switch to moving the image by mouse wheel
    instead of using it for shortcuts
  * add: shortcut actions to move image left/right/up/down
  * add: shortcut actions to got to edges of current image
  * add: setting to adjust autohide of mouse cursor
  * add: allow wheel left/right movement as mouse gestures for
    shortcut
  * add: allow selection of OpenGL backend in settings
  * add: option to load PDF documents with QtPDF instead of poppler
  * add: animate arrows and add small click animation on startup
  * improve: unify look and feel of various elements throughout
    application
  * improve: startup default to mixed setup (integrated and
    popped out) as default option
  * improve: support any image format as icon for context menu
    entry
  * improve: listening to global mouse movements, fixes
    overloading event system
  * improve: don't show context menu entry to add location to
    favorites without pugixml available
  * improve: Escape key in file dialog with files selected
    only removes selection
  * improve: installing pychromecast with cmake is now
    opt-in option
  * improve: crash prevention when scanning for chromecast
    devices with pychromecast
  * fix: finding/linking against (optional) mpv source files
  * fix: proper url encoding for favorite locations
  * fix: compilation with Exiv 0.28.0
- Changes in 3.2:
  * add: advanced sorting by dates stored in exif meta data
  * add: more options for highlighting thumbnails in thumbnail bar
  * add: option to disable thumbnail tooltips
  * add: file dialog: looping thumbnails of images inside subfolders
  * add: file dialog: select files and folders, add file operations
    using global clipboard (incl. shortcuts)
  * add: file dialog: thumbnails are by default shown scaled and
    cropped to fit
  * add: file dialog: typing a string finds next matching file
  * improve: more aggressive freeing of memory when resetting PhotoQt
  * improve: validation check also checks directories
  * improve: detect mouse leaving application window and hide
    elements (main menu, meta data, etc.)
  * improve: reliability of loading and displaying image resolution
  * improve: trash handling on Linux following freedesktop.org
    standard
  * improve: enable MPV support by default, prefer MPV over
    QtMultimedia by default
  * improve: Exiv2: managing BMFF support
  * improve: file dialog: folder follows main image folder when image
    opened from command line
  * improve: file dialog: do not select first entry by default after
    new folder has been loaded
  * improve: file dialog: elide long filenames in the middle
  * improve: file dialog: when mouse cursor leaves fileview reset
    current index
  * improve: find and link to 'Concurrent' module
  * fix: handling of Escape key
  * fix: execution of external shortcuts
  * fix: caching thumbnails of images inside archives
  * fix: correctly removing old animated images from model
    (freeing up memory)
  * fix: double click on image no longer triggers background action
  * fix: window manager titles in wallpaper element were
    unclickable
- Add BuildRequires libQt5PlatformHeaders-devel
* Mon Mar 13 2023 Carsten Ziepke <kieltux@gmail.com>
- update to 3.1:
  * add: 'scale and crop' preview images in file dialog
  * add: 'scale and crop' thumbnails to fill thumbnail square
  * add: option to blur elements in background
  * add: option to reset session when hiding to system tray
  * add: option to always load images at actual scale (incl.
    shortcut to toggle setting)
  * add: option to automatically hide status info and/or window
    buttons if not needed
  * add: enable BMFF meta format in Exiv2 if available and enabled
  * improve: handling of mouse wheel
  * improve: uniform context menus
  * improve: managing external shortcuts
  * improve: managing custom context menu entries
  * improve: file count in file dialog when folder icon is very
    light
  * improve: make splitview handle in file dialog stand out more
  * improve: breadcrumbs dropdown folder list
  * improve: file dialog layout when window is small
  * improve: specify better default Windows font
  * fix: sorting of files/folders in file dialog
  * fix: visual glitches in file dialog
  * fix: specifying font sizes throughout interface
- Changed source URL
* Thu Feb  2 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0:
  * add: shortcut: load random image in folder
  * add: filedialog: forward/backward mouse button navigates through history
  * add: filedialog: access settings manager
  * improve: file dialog: use native path separators
  * improve: file dialog: improve subfolder listing
  * improve: file dialog: breadcrumbs handling
  * improve: file dialog: up/down arrows in icon view moves rows up/down
  * improve: right click and context menus
  * improve: custom menu entries (icons, path, etc.)
  * improve: histogram: support for images other than 32bit
  * improve: face tagger: use click-and-draw instead of click-then-draw to
    mark new faces
  * improve: face tagger:  preserves other meta data
  * improve: performance and resilience for RAW images
  * improve: structure and rendering of SVG icons
  * fix usage of file URI scheme
  * many more bug fixes and improvements
- drop photoqt-fix-building-with-raw.patch (upstream)
* Tue Jan 24 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.9.1
  * fix: language files missing
  * fix: network path handling on Windows
- Changes in 2.9:
  * add/improve: new status information labels
  * improve: always attempt loading of Exiv2 data
  * improve: option to move meta data back behind screen edge
  * improve: replace PNGs icons by SVGs for better scaling
  * improve: new filetype and backup icons
  * improve: small interface updates
  * improve: switch from deprecated appdata to metainfo
  * new shortcuts: __fullscreenToggle, __fitInWindow
  * fix: sorting of files in file and folder model
  * fix: selection of certain localizations
  * fix: calculation of size of pixmap cache
  * fix: visibility of slideshow controls
  * other smaller bug fixes and improvements
- Changes in 2.8:
  * file dialog: preview image can be blurred and/or its colors
    muted
  * file dialog: preview image can be loadedin low (fast) and
    high (slower) resolution
  * file dialog: option to hide tooltip with file details
  * file dialog: reworked context menu of fileview
  * file dialog: tooltip with file details
  * slideshow: fix next/prev buttons during slideshow when
    slideshow paused
  * slideshow: controls turned into floating buttons at bottom
    center
  * shortcuts: support for double clicks
  * navigation: add navigation buttons to window buttons
  * navigation: add zoom to/from setting
  * navigation: add min/max zoom range
  * navigation: option to enable/disable window decoration by
    clicking outside visible image
  * main menu: restyled and regrouped, complementary to context
    menu
  * context menu: restyled and regrouped, complementary to main
    menu
  * metadata: turn into floating element, not hiding behind edge
    anymore
  * file formats: support for Adove Illustrator (AI) file format
  * startup: validate values of some settings, ensuring they fall
    within a valid min/max range
  * interface: pause animated image when element opened on top
  * interface: raise window properly when needed
  * interface: startup background text message font size follows
    window size
  * interface: option to automatically pop out elements if window
    is too small
  * interface: option to set different overlay color in fullscreen
  * general UI updates and color adjustments
- Changes in 2.7:
  * add: support for libvips image library
  * add: support for libmpv video library
  * add: advanced sorting by luminosity
  * add: obtain configuration visually (About) and through
    command line (--show-info)
  * improve: reworked main menu with collapsible sections
  * improve: better performance of obtaining image size info
  * fix: mimetypes where never checked
  * fix: hiding of viewer mode button when shortcut used
  * various improvements and fixes under the hood
- Changes in 2.6:
  * add new image formats: ani, dfont, g4, heic/heif, otf,
    pfa/pfb, pgx, qoi, sixel
  * add: new transitions: explosion, implosion, rotation, random
  * add: advanced sorting (including shortcuts) by: resolution,
    dominant color, average color
  * add: more filter options: file name/extension, resolution,
    file size
  * add: print support
  * add: option to always show 'closing x'
  * improve: general performance improvements
  * remove no longer supported image formats: cgm, fig, fpx, flif,
    gv, sid
  * fix: update with GraphicsMagick caused crash
  * fix: fully hide labels if none are set to be shown
- Add BuildRequires pkgconfig(Qt5PrintSupport)
- Add photoqt-fix-building-with-raw.patch, make raw loader work
  when libraw is compiled without rawspeed support
- Drop post/postun
- Use ImageMagick instead of GraphicsMagick [bsc#1206620]
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.5:
  * add: chromecast support (using pychromecast)
  * add: new startup checks
  * add: new dialog informing user of new install/update
  * add: convert settings, shortcuts, and contextmenu from file based to database based
  * add: command line option to check and attempt to fix configuration
  * add: command line option to reset settings/shortcuts to defaults
  * add: dialog to show debug/log messages
  * add: second desktop file for standalone mode
  * improve: better handling of threading for loading images
  * improve: scrolling by mouse no longer flicks view resulting in better handling
  * improve: handling of imageformats
  * improve: use image providers for setting background image
  * improve: reorder mainmenu entries
  * improve: copying of image to clipboard
  * improve: default startup message, don't show file dialog automatically
  * improve: context menu now standalone window and thus not confined to PhotoQt window
  * improve: graceful fail when ffmpegthumbnailer not available for video files
  * improve: filename inside archives shown on labels in mainview
  * improve: enable build with Exiv 0.25
  * improve: 'Escape' by default calls __open
  * fix/improve: export/import of old and new backup files
  * fix: settingsmanager, handling of modal windows
  * fix: picking color did not handle the absence of transparency well
  * fix: external shortcuts close PhotoQt when 'close' option set
  * fix: zoom-to-position failed in multi-monitor setup when last-left monitor is not used
  * fix: executing external app by shortcut failed handling placeholders
  * fix: slideshow with many images in many subfolders
  * fix: escape html tags in filenames shown on tooltips/labels
  * add: zoom/pinch to position
  * add: click on left/right half of empty area around image can load prev/next image
  * add: option to exclude directories from caching/preloading
  * add: custom filetype icons
  * improve: switch default shortcuts for __copy and __clipboard
  * improve: script to generate data (filetype icons, windows installer script, etc.)
  * fix: loading of metadata
  * fix: replacing placeholders in external shortcuts
  * fix: handling of --thumbs/--no-thumbs at startup
  * fix: reacting to changes to current folder/image
  * fix: change wheel up/down to proper directions
  * windows: make videos playback work on Windows
  * windows: add to software section in settings
  * windows: fix loading userplaces
  * windows: new installer
  * add: context menu (subset of mainmenu options), assign right button to it (if not already in use)
  * add: new shortcuts manager
  * add: command line option to enable/disable system tray
  * add: new internal shortcuts: __viewerMode, __showThumbnails, __showMainMenu,
    __showMetaData, __quickNavigation, __showFaceTags, __keepMetaData, __contextMenu
  * add: restore default configuration, accessible via 'advanced' button in settings manager
  * add: support of JPEG XL format (if qt plugin installed)
  * improve: calling PhotoQt without command line arguments when hidden assumes '--show'
  * improve: use arrows to indicate direction in mouse gestures
  * improve: closing 'x' hidden unless fullscreen or window decoration disabled
  * improve: new format for saving shortcuts
  * improve: handling of command line options
  * improve: keeping track of mouse position
  * fix: load translations for command line help message
  * fix: artifacts in rendered text for scale<1
  * fix: loading rar archives with unrar with non-Latin characters in filenames
  * fix: wrong datatype used for PixmapCache property (was bool but should be int)
  * fix: mirror property of scaled down versions follows main image
  * add: viewer mode for documents/archives, activated through button near top left corner of screen
  * add: quick navigation buttons (added with touchscreens in mind)
  * add: show filename in window title
  * add: show rotation angle in quick info labels
  * add: new button to enter/exit fullscreen mode near top right corner of screen
  * add: show 'unsupported' feedback when trying to tag faces in unsupported file type
  * add: show 'nothing found' message when filter returns nothing
  * add: new PQButton element
  * add/improve: various touch ups and improvements in file dialog, new 'go up a level' button
  * add/improve: Windows build shows 'unsupported' message instead of doing nothing
  * improve: reworked file/folder model, faster and more consistent than before
  * improve: window decoration always visible by default
  * improve: checkbox uses tickmark instead of 'x' for showing checked state
  * improve: limit number of subfolder in slideshows (if enabled) to 100 to avoid getting stuck
  * improve: Windows build no longer depends on QtWinExtras
  * fix: handling of command line options
  * fix: some caching locations pointed to wrong directory
  * fix: handling of single quotation marks in filenames
  * fix: Windows build properly handles drive letters
  * fix: Windows build properly cleans path
  * various smaller bug fixes and improvements all over the place
  * fix: revert default from ImageMagick back to GraphicsMagick (as it was before 2.1)
  * fix: sort images in folder when path passed on to PhotoQt via command line
  * fix: under certain circumstances the directory itself would be added as final 'image'
  * fix: first entry in history of file dialog was always set to home directory
  * fix: crypt key (used e.g. for handling Imgur authentication) now based off hostname
  * fix: back button for history in file dialog barely clickable
  * improve: image format handling (sqlite based)
  * improve: loading of image files
  * improve: startup speed when PhotoQt has not been either updated or freshly installed
  * improve: handling of popout states
  * improve: shortcut handling when popout window activated
  * improve: make it easier to hit 'close' button top right of main interface without triggering menu
  * improve: files in a folder are filtered more efficiently
  * improve: detection of previously chosen languages
  * improve: reorganizing of handling methods
  * add: welcome screen
  * add: ImageMagick support (choice between GraphicsMagick and ImageMagick possible)
  * add: small buttons to quickly toggle popout status of elements
  * add: proper window titles for popout windows
  * add: slideshow can include images in subfolders
  * add: element to convert images into different format
  * fix: memory leak when loading images with Qt
  * fix: caching images
  * fix: sometimes thumbnail would be loaded instead of full image
  * fix: image are loaded asynchronously, without blocking main interface
  * Complete re-write, minimum Qt version now 5.9
  * add: more image transitions
  * add: pop out elements
  * add: hide cursor when not moved
  * add: video support
  * add: support for AVIF file format
  * add: sort images by timestamp stored in exif meta data
  * add: better threading of thumbnail creation
  * improve: rewritten image engine
  * improve: raw thumbnails are loaded from metadata (where available)
  * improve: new element to open files
  * improve: new settings manager with cleaner interface
  * improve: new 'loading' indicator
  * improve: fewer/no workarounds necessary due to re-write
- drop 0001-Switch-to-FindLibExiv2-from-ECM-5.53.0.patch
  0002-Fix-build-with-exiv2-0.27.patch
  photoqt-1.7-link.patch: obsolete
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to fix build with Exiv2 0.27:
  0001-Switch-to-FindLibExiv2-from-ECM-5.53.0.patch
  0002-Fix-build-with-exiv2-0.27.patch
* Wed Jun  6 2018 avvissu@yandex.by
- Update to 1.7.1:
  * Fix: Animated images would not load
  * Fix: The more images in a directory the slower PhotoQt would
    load first image
  * Fix: Deleting an image would lead to infinite 'loading' indicator
  * Fix: List of releases in appdata file was in reverse order
  * Add: Show 'busy' cursor while loading a Loader item
* Fri May 25 2018 bwiedemann@suse.com
- Use constant CRYPTKEY to make build reproducible (boo#1062303)
* Wed May 16 2018 avvissu@yandex.by
- Update to 1.7:
  * Add: proper support for formats supported by KDE image plugins
  * Add: FreeImage image library
  * Add: DevIL image library
  * Add: Poppler (for: PDF (inline or document viewer mode))
  * Add: libarchive (for: comic book archives, ZIP, RAR, 7ZIP, TAR)
  * Add: unrar (Unix-only) (for: better RAR support)
  * Add: Detect images also by MIME type and not only by file ending
  * Add: Detect, display and manage people tags (stored in XMP metadata)
  * Add: Current Zoom level to quick info label
  * Add: Setting to adjust step size of zoom
  * Add: Basic Window Management (using quick info labels)
  * Improve: GraphicsMagick speed
  * Improve: Usability of PhotoQt on small screens
  * Improve: More efficient and compact fileformats handling
  * Improve: overall speed and responsiveness
  * Fix: Trash for files on removable drive
  * Fix: Masking image display shown when needed
  * Fix: many small bugs
- Fix build with freeimage (photoqt-1.7-link.patch)
- Add dependencies: extra-cmake-modules, pkgconfig(libarchive),
  pkgconfig(poppler-qt5), pkgconfig(IL), freeimage-devel
- Spec file cleanup
* Wed Feb 21 2018 avvissu@yandex.by
- Update to 1.6:
  * see: /usr/share/doc/packages/photoqt/CHANGELOG
* Wed May 10 2017 jengelh@inai.de
- Ensure neutrality of description.
* Wed Jan 18 2017 avvissu@yandex.by
- Update to 1.5.1:
  * see: /usr/share/doc/packages/photoqt/CHANGELOG
* Thu Jan 12 2017 avvissu@yandex.by
- Update to 1.5:
  * see: /usr/share/doc/packages/photoqt/CHANGELOG
* Fri Nov  4 2016 avvissu@yandex.by
- Update to 1.4.1.1:
  * see: /usr/share/doc/packages/photoqt/CHANGELOG
- Add support libraw
- Update the icon theme cache
- Drop photoqt-1.2_invalid-desktopfile.patch
* Sat Jun 20 2015 avvissu@yandex.ru
- Update to 1.2.1:
  * see: /usr/share/doc/packages/photoqt/CHANGELOG
* Tue May 12 2015 avvissu@yandex.ru
- Initial release
